from .main import setAccount,sendEmail

__all__=[
    'setAccount',
    'sendEmail'
]


__version__='0.9.1'
__license__='GPL-2.0 License'
__author__='Tiancheng Jiao'
__url__='https://github.com/jtc1246/outlook'
__author_email__='jtc1246@outlook.com'
__description__='A simple email sender for Outlook'